

<p align="center"><a href="https://fusejs.io" target="_blank" rel="noopener noreferrer"><img width="200" src="https://fusejs.io/assets/images/logo.png" alt="Fuse.js logo"></a></p>

<p align="center">
  <a alt="Build Status" href="http://travis-ci.org/krisk/Fuse"><img src="https://secure.travis-ci.org/krisk/Fuse.svg?branch=master" /></a>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/v/fuse.js.svg" alt="Version"/></a>
  <a href="https://npmcharts.com/compare/fuse.js?minimal=true"><img src="https://img.shields.io/npm/dm/fuse.js.svg" alt="Downloads" /></a>
    <a href="https://github.com/krisk/Fuse/graphs/contributors"><img src="https://img.shields.io/github/contributors/krisk/fuse.svg" alt="Contributors" /></a>
  <a href="https://www.npmjs.com/package/fuse.js"><img src="https://img.shields.io/npm/l/fuse.js.svg" alt="License"></a>
<!--   <a href="https://discord.gg/QF4B9sf"><img src="https://img.shields.io/badge/chat-on%20discord-7289da.svg" alt="Chat"></a> -->
</p>

<!--special end-->
---

## Introduction

Fuse.js is a lightweight fuzzy-search, in JavaScript, with zero dependencies.

## Documentation

To checkout out [live examples](https://fusejs.io) and docs, visit [fusejs.io](https://fusejs.io).

## Installation

__NPM__

NPM is the recommended installation method. It pairs nicely with a CommonJS module bundler such as [Webpack](http://webpack.github.io/) or [Browserify](http://browserify.org/).

```sh
# latest stable
$ npm install --save fuse.js
```

__CDN__

Available on [cdnjs](https://cdnjs.cloudflare.com/ajax/libs/fuse.js/3.4.5/fuse.min.js) (see the latest version on [the Releases page](https://github.com/krisk/Fuse/releases)).

## Contributing

### Coding conventions

Code should be run through [Standard Format](https://www.npmjs.com/package/standard-format).

### Testing

Before submitting a pull request, please add relevant tests in `test/index.js`, and execute them via `npm test`.

